/*
 * Copyright 2022 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef LAUNCHERITEM_H
#define LAUNCHERITEM_H

#include <QObject>
#include <QtQml>

struct LauncherItemPrivate;
class LauncherItem : public QObject
{
    Q_OBJECT
#if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
    QML_ELEMENT
#endif

    Q_PROPERTY(QString name READ name WRITE setName NOTIFY nameChanged)
    Q_PROPERTY(int id READ id WRITE setId NOTIFY idChanged)
    Q_PROPERTY(int type READ type WRITE setType NOTIFY typeChanged)
    Q_PROPERTY(int pageIndex READ pageIndex WRITE setPageIndex NOTIFY pageIndexChanged)
    Q_PROPERTY(QString icon READ icon WRITE setIcon NOTIFY iconChanged)
    Q_PROPERTY(QString desktopFile READ desktopFile WRITE setDesktopFile NOTIFY desktopFileChanged)
    Q_PROPERTY(int location READ location WRITE setLocation NOTIFY locationChanged)
    Q_PROPERTY(int rowSpan READ rowSpan WRITE setRowSpan NOTIFY rowSpanChanged)
    Q_PROPERTY(int columnSpan READ columnSpan WRITE setColumnSpan NOTIFY columnSpanChanged)
    Q_PROPERTY(int state READ state WRITE setState NOTIFY stateChanged)
    Q_PROPERTY(bool editable READ editable WRITE setEditable NOTIFY editableChanged)
    Q_PROPERTY(bool selected READ selected WRITE setSelected NOTIFY selectedChanged)
    Q_PROPERTY(bool appOpen READ appOpen WRITE setAppOpen NOTIFY appOpenChanged)
    Q_PROPERTY(int windowId READ windowId WRITE setWindowId NOTIFY windowIdChanged)

public:
    enum ItemType {
        AppIcon,
        Group,
        Container,
        Widget,
        Placeholder,
        AddIcon,
    };
    enum ItemState {
        Normal,
        Editable,
        Selectable,
    };
    Q_ENUMS(ItemType)
    Q_ENUMS(ItemState)

    explicit LauncherItem(QObject *parent = nullptr);
    LauncherItem(const LauncherItem &other);
    ~LauncherItem();
    LauncherItem &operator= (const LauncherItem &other) {
        this->setName(other.name());
        this->setId(other.id());
        this->setType(other.type());
        this->setPageIndex(other.pageIndex());
        this->setIcon(other.icon());
        this->setDesktopFile(other.desktopFile());
        this->setLocation(other.location());
        this->setRowSpan(other.rowSpan());
        this->setColumnSpan(other.columnSpan());
        this->setState(other.state());
        this->setEditable(other.editable());
        this->setSelected(other.selected());
        this->setAppOpen(other.appOpen());
        this->setWindowId(other.windowId());

        return *this;
    }

    QString name() const;
    void setName(const QString &name);

    int id() const;
    void setId(const int &id);

    int type() const;
    void setType(const int &type);

    int pageIndex() const;
    void setPageIndex(const int &pageIndex);

    QString icon() const;
    void setIcon(const QString &icon);

    QString desktopFile() const;
    void setDesktopFile(const QString &desktopFile);

    int location() const;
    void setLocation(const int &location);

    int rowSpan() const;
    void setRowSpan(const int &rowSpan);

    int columnSpan() const;
    void setColumnSpan(const int &columnSpan);

    int state() const;
    void setState(const int &state);

    bool editable() const;
    void setEditable(const bool &editable);

    bool selected() const;
    void setSelected(bool selected);

    bool appOpen() const;
    void setAppOpen(const bool &appOpen);

    int windowId() const;
    void setWindowId(const int &windowId);


Q_SIGNALS:
    void nameChanged();
    void idChanged();
    void typeChanged();
    void indexChanged();
    void pageIndexChanged();
    void iconChanged();
    void desktopFileChanged();
    void locationChanged();
    void rowSpanChanged();
    void columnSpanChanged();
    void stateChanged();
    void editableChanged();
    void selectedChanged();
    void appOpenChanged();
    void windowIdChanged();

private:
    LauncherItemPrivate *p;
};

#endif // LAUNCHERITEM_H
