/*
 * Copyright 2022 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "appmanager.h"
#include <QDBusError>

AppManager::AppManager(QObject *parent)
    : QObject(parent)
    , m_appManagerInterface(new AppManagerInterface("com.kylin.AppManager", "/com/kylin/AppManager", QDBusConnection::sessionBus()))
{
    if (!m_appManagerInterface->isValid()) {
        qWarning() << "Connect to com.kylin.AppManager dbus service failed!" << m_appManagerInterface->lastError();
    }
    m_userName = getUserName();
}

void AppManager::runApplication(const QString &desktopFile)
{
    qDebug()<<"---dcf---"<<desktopFile;
    bool ret = m_appManagerInterface->LaunchApp(desktopFile);;
    if (!ret) {
        qWarning() << "Run Application failed!" << desktopFile;
    }
}

QList<quint32> AppManager::runningApplications()
{
    QList<quint32> runningAppWids;
    return runningAppWids;
}

void AppManager::removeApplication(const QString &desktopFile)
{
    Q_UNUSED(desktopFile);
    // 区分apt安装或者apk安装方式分别调用各自的卸载接口
    qDebug() <<__FUNCTION__<< desktopFile;
    QSettings desktop(desktopFile, QSettings::IniFormat);
    QString desktopCmd = desktop.value("Desktop Entry/Exec").toString();
    // kmre应用卸载
    if (desktopCmd.contains("/usr/bin/startapp")) {
        qDebug() << " ---kmre应用卸载---分支";
        if (!QDBusConnection::sessionBus().isConnected()) {
            qDebug()<<"Cannot connect to the cn.kylinos.Kmre.Manager D-Bus sessionBus.";
            return;
        }
        //调用系统cn.kylinos.Kmre.Manager服务
        QDBusInterface apkRemoveFace("cn.kylinos.Kmre.Manager",
                             "/cn/kylinos/Kmre/Manager",
                             "cn.kylinos.Kmre.Manager",
                             QDBusConnection::sessionBus());
        if (apkRemoveFace.isValid()) {
            qDebug()<<"---apkRemoveFace---";
            QStringList strList = desktopCmd.split(" ");
            apkRemoveFace.asyncCall("uninstallApp", strList.at(1));
        } else {
            qDebug()<<"apkRemoveFace 无法调用到PurgePackages方法";
        }
    } else {
        qDebug() << " ---apt应用卸载---分支";
        if (!QDBusConnection::systemBus().isConnected()) {
            qDebug()<<"Cannot connect to the  com.kylin.systemupgrade D-Bus systemBus.";
            return;
        }
        //调用系统com.kylin.systemupgrade服务
        QDBusInterface aptRemoveFace("com.kylin.systemupgrade",
                             "/com/kylin/systemupgrade",
                             "com.kylin.systemupgrade.interface",
                             QDBusConnection::systemBus());

        if (aptRemoveFace.isValid()) {
            qDebug()<<"---aptRemoveFace---"<<desktopFile;
            QString pkgName = getPkgNameByDesktop(desktopFile);
            qDebug()<<"---pkgName---"<<pkgName;
            QStringList purgeList;
            purgeList.append(pkgName);
            qDebug()<<"---m_userName---"<<m_userName;
            aptRemoveFace.asyncCall("PurgePackages", purgeList, m_userName);
        } else {
            qDebug()<<"aptRemoveFace 无法调用到PurgePackages方法";
        }
    }
}

void AppManager::runApplicationConfig(const QString &desktopFile, const QStringList &Config)
{
    bool retConfig = m_appManagerInterface->LaunchAppWithArguments(desktopFile, Config);
    qDebug()<<"===retConfig"<<retConfig;
    if (!retConfig) {
        qWarning() << "Run ApplicationConfig failed!" << desktopFile;
    }
}

QString AppManager::AppDesktopFileNameByPid(qlonglong pid)
{
    return m_appManagerInterface->AppDesktopFileNameByPid(pid);
}

QString AppManager::getUserName()
{
    QString userName = qgetenv("USER");
    qDebug() <<"1---userName---"<< userName;
    if (userName.isEmpty()){
        userName = qgetenv("USERNAME");
        qDebug() <<"2---userName---"<< userName;
    }
    return userName;
}

QString AppManager::getPkgNameByDesktop(const QString &desktopFile)
{
    qDebug()<<"---getPkgNameByDesktop---"<<desktopFile;
    std::string packName = "dpkg -S " + desktopFile.toStdString();
    char nameBuff[100] = "";
    FILE* fp = popen(packName.c_str(),"r");
    fgets(nameBuff, 100, fp);
    pclose(fp);
    std::string pkgInfo = nameBuff;
    if(pkgInfo.empty()){
        qDebug()<<"---pkgInfo.isEmpty()---";
    }
    std::string pkg = std::string(pkgInfo.begin(),pkgInfo.begin() + pkgInfo.find(':'));
    qDebug()<<"---pkg---"<<pkg.c_str();
//    m_pkgName = QString::fromStdString(pkg);
    QString pkgName = QString::fromStdString(pkg);
    return pkgName;
}
