/*
 * Copyright (C) 2020 The Qt Company Ltd.
 * Copyright 2022 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef APPMANAGERINTERFACE_H
#define APPMANAGERINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface com.kylin.AppManager
 */
class AppManagerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "com.kylin.AppManager"; }

public:
    AppManagerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~AppManagerInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> AddToWhiteList(const QString &desktopFile, const QString &option)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(desktopFile) << QVariant::fromValue(option);
        return asyncCallWithArgumentList(QStringLiteral("AddToWhiteList"), argumentList);
    }

    inline QDBusPendingReply<QString> AppDesktopFileNameByPid(qlonglong pid)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(pid);
        return asyncCallWithArgumentList(QStringLiteral("AppDesktopFileNameByPid"), argumentList);
    }

    inline QDBusPendingReply<bool> LaunchApp(const QString &desktopFile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(desktopFile);
        return asyncCallWithArgumentList(QStringLiteral("LaunchApp"), argumentList);
    }

    inline QDBusPendingReply<bool> LaunchAppWithArguments(const QString &desktopFile, const QStringList &args)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(desktopFile) << QVariant::fromValue(args);
        return asyncCallWithArgumentList(QStringLiteral("LaunchAppWithArguments"), argumentList);
    }

    inline QDBusPendingReply<bool> RemoveFromWhiteList(const QString &desktopFile, const QString &option)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(desktopFile) << QVariant::fromValue(option);
        return asyncCallWithArgumentList(QStringLiteral("RemoveFromWhiteList"), argumentList);
    }

    inline QDBusPendingReply<> SetPowerSavingModeEnable(bool enable)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(enable);
        return asyncCallWithArgumentList(QStringLiteral("SetPowerSavingModeEnable"), argumentList);
    }

    inline QDBusPendingReply<QStringList> WhiteListsOfApp(const QString &desktopFile)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(desktopFile);
        return asyncCallWithArgumentList(QStringLiteral("WhiteListsOfApp"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace com {
  namespace kylin {
    typedef ::AppManagerInterface AppManager;
  }
}
#endif
