/*
 * Copyright 2022 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include <QApplication>
#include <QQmlApplicationEngine>
#include <QQmlContext>
#include <QtPlatformHeaders/QXcbWindowFunctions>
#include <QQuickView>
#if 0
#if defined (Q_PROCESSOR_X86_64) || defined (Q_PROCESSOR_ARM_64)
#include <QBreakpadHandler.h>
#endif
#endif
#include "base/launcheritem.h"
#include "base/categoryitem.h"
#include "core/modelmanager.h"
#include "core/appmanager.h"
#include "core/pluginitem.h"
#include "logger.h"
//#include "KylinItemView/kquickgridview.h"
#include "utils/getscreenshot.h"
#include "utils/desktopbackground.h"
#include "ukui-log4qt.h"
#include "utils/generalsetting.h"
#include "utils/wirelessstatus.h"
#include "utils/wiredlinkstate.h"
#include "utils/accountlogout.h"
#include "utils/blurhelper.h"
#include "utils/gettaskbarvalue.h"
#include "base/trayicon.h"
#include "utils/taskbarmask.h"
#include "base/sidebarstate.h"
#include <QQuickStyle>

int main(int argc, char *argv[])
{
#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
#endif

    QApplication app(argc, argv);

#if 0
#if defined (Q_PROCESSOR_X86_64) || defined (Q_PROCESSOR_ARM_64)
    QBreakpadInstance.setDumpPath(QLatin1String("/tmp/kylin-tablet-desktop-general"));
#endif
#endif

#ifndef QT_DEBUG
    initUkuiLog4qt("kylin-tablet-desktop");
#endif
    QQuickView qmlView;
    QQuickStyle::setStyle("org.ukui.style");

    // qml logger
    // usage in qml:
    // QmlLogger.debug(msg);QmlLogger.warning(msg); ...
    common::QmlLogger qmlLogger;

    qmlView.engine()->addImportPath("qrc:/ui/qml");
    qmlView.engine()->rootContext()->setContextProperty("qmlLogger", &qmlLogger);

    ModelManager modelMgr;
    qmlView.engine()->rootContext()->setContextProperty("modelManager", &modelMgr);

    AppManager appMgr;
    qmlView.engine()->rootContext()->setContextProperty("appManager", &appMgr);

    TrayIcon trayIcon;
    qmlView.engine()->rootContext()->setContextProperty("trayIcon", &trayIcon);

    SidebarState sidebarState;
    qmlView.engine()->rootContext()->setContextProperty("sidebarState", &sidebarState);

    // qml js:
    // if (type == LauncherItem.AppIcon) {} ...
#if QT_VERSION <= QT_VERSION_CHECK(5,12,8)
    qmlRegisterType<LauncherItem>("com.kylin.tablet", 1, 0, "LauncherItem");
    qmlRegisterType<CategoryItem>("com.kylin.tablet", 1, 0, "CategoryItem");
    qmlRegisterType<GetScreenShot>("com.kylin.tablet", 1, 0, "ScreenShot");
    qmlRegisterType<DesktopBackground>("com.kylin.tablet", 1, 0, "Background");
//    qmlRegisterType<KQuickGridView>("com.kylin.tablet", 1, 0, "KGridView");
    qmlRegisterType<LauncherItem>("com.kylin.tablet", 1, 0, "LauncherItem");
    qmlRegisterType<CGeneralSetting>("MyGeneralSetting", 1, 0, "CGeneralSetting");
    qmlRegisterType<WirelessStatus>("com.kylin.tablet", 1, 0, "WirelessStatus");
    qmlRegisterType<WiredLinkState>("com.kylin.tablet", 1, 0, "WiredLinkState");
    qmlRegisterType<AccountLogout>("com.kylin.tablet", 1, 0, "AccountLogout");
    qmlRegisterType<BlurHelper>("com.kylin.tablet", 1, 0, "BlurHelper");
    qmlRegisterType<PluginItem>("com.kylin.tablet", 1, 0, "PluginItem");
    qmlRegisterType<TrayIcon>("com.kylin.tablet", 1, 0, "TrayIcon");
    qmlRegisterType<TaskbarMask>("com.kylin.tablet", 1, 0, "TaskbarMask");
#endif

    qmlView.setSource(QUrl("qrc:/ui/qml/main.qml"));
    QXcbWindowFunctions::setWmWindowType(&qmlView, QXcbWindowFunctions::Desktop);
    qmlView.showFullScreen();
    qmlView.resize(1920, 1080);
    qmlView.rootObject()->setState("Show");

    return app.exec();
}
