/*
 * Copyright 2022 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "gettaskbarvalue.h"
#include <QDateTime>
#include <QPixmap>
#include <QFile>
#include <kdesktopfile.h>
#include <QList>

GetTaskbarValue::GetTaskbarValue(ModelManager *parent) :
    QObject(parent)
    , taskbarModelManager(parent)
    , appManagerInterface(new AppManagerInterface("com.kylin.AppManager", "/com/kylin/AppManager", QDBusConnection::sessionBus()))

{
    if (!appManagerInterface->isValid()) {
        qWarning() << "Connect to com.kylin.AppManager dbus service failed!" << appManagerInterface->lastError();
    }
    connect(WindowManager::self(), &WindowManager::windowAdded, this, &GetTaskbarValue::appWindowOpen);
    connect(WindowManager::self(), &WindowManager::windowRemoved, this, &GetTaskbarValue::setAppClose);
}

GetTaskbarValue::~GetTaskbarValue()
{
    //    delete taskbarModelManager;
}

void GetTaskbarValue::setWindowDesktopFileName(quint32 wid, const QString &fileName)
{
    m_isOpenWindows[fileName].push_back(wid);
}

void GetTaskbarValue::appWindowOpen(WindowId wid)
{
    qDebug() << "open----" <<wid;
    for(auto widList = m_isOpenWindows.begin(); widList != m_isOpenWindows.end(); widList++) {
        for(auto j = 0; j < widList->count(); j++) {
            if (widList->at(j) == wid) {
                qDebug() << "avtivatewindow wid->" << widList->at(j);
                WindowManager::activateWindow(wid);
                return;
            }
        }
    }

    qDebug() << "---open pid--->" << WindowManager::getPid(wid);

    QString desktopName = appManagerInterface->AppDesktopFileNameByPid(WindowManager::getPid(wid));
    qDebug() << "desktopName---->" <<desktopName;
    if (desktopName.isEmpty()) {
        qDebug() << "desktop is null";
        return;
    }

    QString desktopFileName = taskbarModelManager->findDesktopNameFromTaskbar(desktopName);
    if (desktopFileName.isEmpty())
    {
        desktopFileName = taskbarModelManager->findDesktopName(desktopName);
        if (desktopFileName.isEmpty())
        {
            return;
        }
        else
        {
            QString iconFileName = taskbarModelManager->findIconPath(desktopFileName);
            m_isOpenWindows[desktopName].push_back(wid);
            taskbarModelManager->addWindowIconToTaskbar(iconFileName, desktopFileName, wid.toInt());
        }
    }
    else
    {
        // 该应用在任务栏，设置为打开状态
        taskbarModelManager->setAppOpenState(desktopName, wid.toInt());
        m_isOpenWindows[desktopName].push_back(wid);
    }
}
void GetTaskbarValue::setAppClose(WindowId wid)
{
    qDebug() << "app close wid:" << wid;
    for(auto widList = m_isOpenWindows.begin(); widList != m_isOpenWindows.end(); widList++) {
        for(auto j = 0; j < widList->count(); j++) {
            if (widList->at(j) == wid) {
                if (widList->count() == 1) {
                    QString desktopName = widList.key();
                    if (taskbarModelManager->findDesktopName(desktopName).isEmpty()) {
                        taskbarModelManager->setAppCloseState(desktopName);
                    } else {
                        taskbarModelManager->removeAppIconFromTaskBar(desktopName);
                    }
                    m_isOpenWindows.erase(widList);
                } else {
                    qDebug() << "remove window" <<widList->at(j);
                    widList->removeAt(j);

                    QString desktopName = appManagerInterface->AppDesktopFileNameByPid(WindowManager::getPid(wid));
                    taskbarModelManager->changeAppWindowWid(desktopName, wid.toInt(), widList->at(0).toInt());
                }
                return;
            }
        }
    }
}
